@@ -1,5 +1,6 @@
 from .config import DashConfig
 from .guild import Guild
 from .application import Application
+from .user import User
 
-__all__ = ("DashConfig", "Guild", "Application")
\ No newline at end of file
+__all__ = ("DashConfig", "Guild", "Application", "User")
\ No newline at end of file
